==> nextcloud-14.0.1.tgz: nextcloud/apps/comments/l10n/tr.js <==
OC.L10N.register(
    "comments",
    {
    "Edit comment" : "Yorumu düzenle",
    "Delete comment" : "Yorumu sil",
    "New comment …" : "Yorum ekle ...",
    "Post" : "Gönder",
    "Cancel" : "İptal",
    "[Deleted user]" : "[Silinmiş kullanıcı]",
    "Comments" : "Yorumlar",
    "No comments yet, start the conversation!" : "Henüz bir yorum yapılmamış! Bir görüşme başlatın!",
    "More comments …" : "Diğer yorumlar ...",
    "Save" : "Kaydet",
    "Allowed characters {count} of {max}" : "Yazılabilecek karakter sayısı {count}/{max}",
    "Error occurred while retrieving comment with ID {id}" : "{id} kodlu yorum alınırken sorun çıktı",
    "Error occurred while updating comment with id {id}" : "{id} kodlu yorum güncellenirken sorun çıktı",
    "Error occurred while posting comment" : "Yorum gönderilirken sorun çıktı",
    "_%n unread comment_::_%n unread comments_" : ["%n okunmamış yorum","%n okunmamış yorum"],
    "Comment" : "Yorum",
    "You commented" : "Yorum yaptınız",
    "%1$s commented" : "%1$s yorumlanmış",
    "{author} commented" : "{author} yorum yaptı",
    "You commented on %1$s" : "%1$s hakkında yorum yaptınız",
    "You commented on {file}" : "{file} hakkında yorum yaptınız",
    "%1$s commented on %2$s" : "%1$s, %2$s için yorum yaptı",
    "{author} commented on {file}" : "{author}, {file} hakkında yorum yaptı",
    "<strong>Comments</strong> for files" : "Dosyalar için <strong>yorumlar</strong>",
    "You were mentioned on “%s”, in a comment by a user that has since been deleted" : "\"%s\" hakkında bir yorumda silinmiş bir kullanıcı tarafından anıldınız",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "“{file}” hakkında bir yorumda silinmiş bir kullanıcı tarafından anıldınız",
    "%1$s mentioned you in a comment on “%2$s”" : "%1$s, “%2$s” hakkındaki bir yorumda sizden bahsetti",
    "{user} mentioned you in a comment on “{file}”" : "{user}, “{file}” hakkındaki bir yorumda sizden bahsetti",
    "Files app plugin to add comments to files" : "Dosyalara notlar eklenmesini sağlayan dosyalar uygulaması eki",
    "Unknown user" : "Bilinmeyen kullanıcı",
    "A (now) deleted user mentioned you in a comment on “%s”" : "Bir (artık) silinmiş kullanıcı “%s” hakkındaki bir yorumda sizden bahsetti",
    "A (now) deleted user mentioned you in a comment on “{file}”" : "Bir (artık) silinmiş kullanıcı “{file}” hakkındaki bir yorumda sizden bahsetti"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-18.0.6.tgz: nextcloud/apps/comments/l10n/tr.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Yorumlar",
    "You commented" : "Yorum yaptınız",
    "%1$s commented" : "%1$s yorumlanmış",
    "{author} commented" : "{author} yorum yaptı",
    "You commented on %1$s" : "%1$s hakkında yorum yaptınız",
    "You commented on {file}" : "{file} hakkında yorum yaptınız",
    "%1$s commented on %2$s" : "%1$s, %2$s için yorum yaptı",
    "{author} commented on {file}" : "{author}, {file} hakkında yorum yaptı",
    "<strong>Comments</strong> for files" : "Dosyalar için <strong>yorumlar</strong>",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "“{file}” hakkında bir yorumda silinmiş bir kullanıcı tarafından anıldınız",
    "{user} mentioned you in a comment on “{file}”" : "{user}, “{file}” hakkındaki bir yorumda sizi andı",
    "Files app plugin to add comments to files" : "Dosyalara notlar eklenmesini sağlayan dosyalar uygulaması eki",
    "Edit comment" : "Yorumu düzenle",
    "Delete comment" : "Yorumu sil",
    "New comment …" : "Yorum ekle …",
    "Post" : "Gönder",
    "Cancel" : "İptal",
    "[Deleted user]" : "[Silinmiş kullanıcı]",
    "No comments yet, start the conversation!" : "Henüz bir yorum yapılmamış! Bir görüşme başlatın!",
    "More comments …" : "Diğer yorumlar …",
    "Save" : "Kaydet",
    "Allowed characters {count} of {max}" : "Yazılabilecek karakter sayısı {count}/{max}",
    "Error occurred while retrieving comment with ID {id}" : "{id} kodlu yorum alınırken sorun çıktı",
    "Error occurred while updating comment with id {id}" : "{id} kodlu yorum güncellenirken sorun çıktı",
    "Error occurred while posting comment" : "Yorum gönderilirken sorun çıktı",
    "_%n unread comment_::_%n unread comments_" : ["%n okunmamış yorum","%n okunmamış yorum"],
    "_1 new comment_::_{unread} new comments_" : ["1 yeni yorum","{unread} yeni yorum"],
    "Comment" : "Yorum"
},
"nplurals=2; plural=(n > 1);");
